Date: 05 4, 2002 11:44:05 PM

# singlet

## Purpose

Search a node's descendants for a match. Stop looking down when a node is a leaf, has more than one child, or has the BASE attribute set.

## Remarks

s is an alternate form for singlet.

The singlet and base methodology enables attributes and ambiguities to be layered directly into the parse tree nodes, as a "singlet chain." By using the singlet modifer, a rule can pick up the attribute or possibility that is relevant.

## Example

# Even if a prior pass has reduced "per" to a preposition, e.g., _prep,
# this rule will still match the word "per".
_adj <- per [s] capita @@

## See Also

tree, Phrase Element Modifiers.